@@ -3,6 +3,7 @@
 from hammurabi.config import config
 from hammurabi.law import Law
 from hammurabi.pillar import Pillar
+from hammurabi.preconditions.base import Precondition
 from hammurabi.rules.attributes import ModeChanged, OwnerChanged
 from hammurabi.rules.base import Rule
 from hammurabi.rules.directories import (
@@ -26,6 +27,7 @@ from hammurabi.rules.ini import (
     SectionRenamed,
 )
 from hammurabi.rules.operations import Copied, Moved, Renamed
+from hammurabi.rules.templates import TemplateRendered
 from hammurabi.rules.text import LineExists, LineNotExists, LineReplaced
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
